@@ -6,8 +6,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef AKREGATOR_BACKEND_MK4PLUGIN_H
-#define AKREGATOR_BACKEND_MK4PLUGIN_H
+#pragma once
 
 #include "plugin.h"
 
@@ -31,4 +30,3 @@ private:
 } // namespace Backend
 } // namespace Akregator
 
-#endif // AKREGATOR_BACKEND_MK4PLUGIN_H
