@@ -9,6 +9,7 @@
 
 #include "akregator_part.h"
 #include "akregator_debug.h"
+#include "kcmutils_version.h"
 
 #include <MessageViewer/MessageViewerSettings>
 
@@ -38,6 +39,8 @@
 #include <KConfig>
 #include <KMessageBox>
 #include <KNotifyConfigWidget>
+#include <KPluginLoader>
+#include <KPluginMetaData>
 #include <PimCommon/BroadcastStatus>
 #include <QFileDialog>
 #include <kio/filecopyjob.h>
@@ -53,7 +56,10 @@
 #include <QWebEngineSettings>
 #include <kxmlguifactory.h>
 
+#include <kcoreaddons_version.h>
+#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include "akregratormigrateapplication.h"
+#endif
 #include "partadaptor.h"
 #include <QApplication>
 #include <QDomDocument>
@@ -138,10 +144,10 @@ Part::Part(QWidget *parentWidget, QObject *parent, const QVariantList &)
     : KParts::Part(parent)
 {
     mySelf = this;
-
+#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
     AkregratorMigrateApplication migrate;
     migrate.migrate();
-
+#endif
     // Make sure to initialize settings
     Part::config();
     initFonts();
@@ -439,8 +445,8 @@ void Part::flushAddFeedRequests()
         return;
     }
 
-    for (const AddFeedRequest &i : qAsConst(m_requests)) {
-        for (const QString &j : qAsConst(i.urls)) {
+    for (const AddFeedRequest &i : std::as_const(m_requests)) {
+        for (const QString &j : std::as_const(i.urls)) {
             m_mainWidget->addFeedToGroup(j, i.group);
         }
         NotificationManager::self()->slotNotifyFeeds(i.urls);
@@ -604,15 +610,14 @@ void Part::showOptions()
             connect(m_dialog, qOverload<>(&KCMultiDialog::configCommitted), TrayIcon::getInstance(), &TrayIcon::settingsChanged);
         }
 
-        m_dialog->addModule(QStringLiteral("akregator_config_general"));
-        m_dialog->addModule(QStringLiteral("akregator_config_appearance"));
-        m_dialog->addModule(QStringLiteral("akregator_config_archive"));
-        m_dialog->addModule(QStringLiteral("akregator_config_browser"));
-        m_dialog->addModule(QStringLiteral("akregator_config_advanced"));
-        m_dialog->addModule(QStringLiteral("akregator_config_plugins"));
-#ifdef WITH_KUSERFEEDBACK
-        m_dialog->addModule(QStringLiteral("akregator_config_userfeedback"));
+        const QVector<KPluginMetaData> availablePlugins = KPluginLoader::findPlugins(QStringLiteral("pim/kcms/akregator"));
+        for (const KPluginMetaData &metaData : availablePlugins) {
+#if KCMUTILS_VERSION >= QT_VERSION_CHECK(5, 84, 0)
+            m_dialog->addModule(metaData);
+#else
+            m_dialog->addModule(metaData.pluginId());
 #endif
+        }
     }
 
     m_dialog->show();
