@@ -5,8 +5,7 @@
 
     SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
-#ifndef AKREGATOR_ARTICLEMODEL_H
-#define AKREGATOR_ARTICLEMODEL_H
+#pragma once
 
 #include <QAbstractTableModel>
 
@@ -71,4 +70,3 @@ private:
 };
 } // namespace Akregator
 
-#endif // AKREGATOR_ARTICLEMODEL_H
