@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef ARTICLEVIEWERWEBENGINEPAGE_H
-#define ARTICLEVIEWERWEBENGINEPAGE_H
+#pragma once
 
 #include <WebEngineViewer/WebEnginePage>
 namespace Akregator
@@ -17,9 +16,6 @@ public:
     explicit ArticleViewerWebEnginePage(QObject *parent = nullptr);
     ~ArticleViewerWebEnginePage() override;
 
-Q_SIGNALS:
-    void urlClicked(const QUrl &url);
-
 protected:
     bool acceptNavigationRequest(const QUrl &url, NavigationType type, bool isMainFrame) override;
 
@@ -28,4 +24,3 @@ private:
     void onLoadProgress();
 };
 }
-#endif // ARTICLEVIEWERWEBENGINEPAGE_H
