@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef AKREGATOR_FETCHQUEUE_H
-#define AKREGATOR_FETCHQUEUE_H
+#pragma once
 
 #include "akregator_export.h"
 #include <QObject>
@@ -65,4 +64,3 @@ private:
 };
 } // namespace Akregator
 
-#endif // AKREGATOR_FETCHQUEUE_H
