@@ -65,9 +65,12 @@
 
 #include <PimCommon/NetworkManager>
 #include <algorithm>
+#include <chrono>
 #include <memory>
 #include <webengine/webengineframe.h>
 
+using namespace std::chrono_literals;
+
 using namespace Akregator;
 
 MainWidget::~MainWidget()
@@ -247,12 +250,12 @@ MainWidget::MainWidget(Part *part, QWidget *parent, ActionManagerImpl *actionMan
 
     m_fetchTimer = new QTimer(this);
     connect(m_fetchTimer, &QTimer::timeout, this, &MainWidget::slotDoIntervalFetches);
-    m_fetchTimer->start(1000 * 60);
+    m_fetchTimer->start(1min);
 
     // delete expired articles once per hour
     m_expiryTimer = new QTimer(this);
     connect(m_expiryTimer, &QTimer::timeout, this, &MainWidget::slotDeleteExpiredArticles);
-    m_expiryTimer->start(3600 * 1000);
+    m_expiryTimer->start(1h);
 
     m_markReadTimer = new QTimer(this);
     m_markReadTimer->setSingleShot(true);
@@ -384,7 +387,7 @@ void MainWidget::sendArticle(bool attach)
 
 void MainWidget::cleanUpDownloadFile()
 {
-    for (QPointer<Akregator::DownloadArticleJob> job : qAsConst(mListDownloadArticleJobs)) {
+    for (QPointer<Akregator::DownloadArticleJob> job : std::as_const(mListDownloadArticleJobs)) {
         if (job) {
             job->forceCleanupTemporaryFile();
         }
@@ -685,7 +688,7 @@ void MainWidget::slotFeedAdd()
 
 void MainWidget::addFeed(const QString &url, TreeNode *after, Folder *parent, bool autoExec)
 {
-    auto *cmd(new CreateFeedCommand(this));
+    auto cmd(new CreateFeedCommand(this));
     cmd->setParentWidget(this);
     cmd->setPosition(parent, after);
     cmd->setRootFolder(m_feedList->allFeedsFolder());
