@@ -8,8 +8,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef AKREGATOR_MAINWIDGET_H
-#define AKREGATOR_MAINWIDGET_H
+#pragma once
 
 #include "akregatorpart_export.h"
 #include "articleviewer-ng/webengine/articleviewerwebenginewidgetng.h"
@@ -62,7 +61,7 @@ public:
 
     /** destructor.  Note that cleanups should be done in
     slotOnShutdown(), so we don't risk accessing self-deleting objects after deletion. */
-    ~MainWidget();
+    ~MainWidget() override;
 
     /** saves settings. Make sure that the Settings singleton is not destroyed yet when saveSettings is called */
     void saveSettings();
@@ -277,4 +276,3 @@ private:
 };
 } // namespace Akregator
 
-#endif // AKREGATOR_MAINWIDGET_H
