@@ -6,8 +6,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef AKREGATOR_MAINWINDOW_H
-#define AKREGATOR_MAINWINDOW_H
+#pragma once
 
 #include <kio/job.h>
 #include <kparts/mainwindow.h>
@@ -15,7 +14,8 @@
 #include <QPointer>
 
 class KSqueezedTextLabel;
-
+class KHamburgerMenu;
+class KToggleAction;
 namespace Akregator
 {
 class Part;
@@ -44,7 +44,7 @@ public:
      Loads the part
      @return Whether the part has been successfully created or not.
      */
-    Q_REQUIRED_RESULT bool loadPart();
+    bool loadPart();
 
 public Q_SLOTS:
     void slotClearStatusText();
@@ -80,9 +80,11 @@ private Q_SLOTS:
     void slotOnShutdown();
 
 private:
+    void updateHamburgerMenu();
     QPointer<Akregator::Part> m_part;
     KSqueezedTextLabel *const m_statusLabel;
+    KHamburgerMenu *mHamburgerMenu = nullptr;
+    KToggleAction *mShowMenuBarAction = nullptr;
 };
 } // namespace Akregator
 
-#endif // AKREGATOR_MAINWINDOW_H
